@@ -390,7 +390,7 @@ real_select_all (NautilusFilesView *files_view)
 static GtkWidget *
 get_first_selected_item_ui (NautilusViewIconController *self)
 {
-    g_autoptr (GList) selection = NULL;
+    g_autolist (NautilusFile) selection = NULL;
     NautilusFile *file;
     NautilusViewItemModel *item_model;
 
@@ -546,7 +546,7 @@ get_icon_size_for_zoom_level (NautilusCanvasZoomLevel zoom_level)
 }
 
 static gint
-get_default_zoom_level ()
+get_default_zoom_level (void)
 {
     NautilusCanvasZoomLevel default_zoom_level;
 
@@ -664,7 +664,7 @@ real_compute_rename_popover_pointing_to (NautilusFilesView *files_view)
 static GdkRectangle *
 real_reveal_for_selection_context_menu (NautilusFilesView *files_view)
 {
-    g_autoptr (GList) selection = NULL;
+    g_autolist (NautilusFile) selection = NULL;
     NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
     GtkWidget *item_ui;
 
@@ -698,7 +698,7 @@ on_button_press_event (GtkWidget *widget,
                        gpointer   user_data)
 {
     NautilusViewIconController *self;
-    g_autoptr (GList) selection = NULL;
+    g_autolist (NautilusFile) selection = NULL;
     GtkWidget *child_at_pos;
     GdkEventButton *event_button;
 
@@ -744,8 +744,6 @@ on_button_press_event (GtkWidget *widget,
         }
     }
 
-    g_list_foreach (selection, (GFunc) g_object_unref, NULL);
-
     return GDK_EVENT_STOP;
 }
 
@@ -807,7 +805,7 @@ action_sort_order_changed (GSimpleAction *action,
                            gpointer       user_data)
 {
     const gchar *target_name;
-    const SortConstants *sorts_constants;
+    const SortConstants *sort_constants;
     NautilusViewModelSortData sort_data;
     NautilusViewIconController *self;
 
@@ -819,14 +817,14 @@ action_sort_order_changed (GSimpleAction *action,
 
     self = NAUTILUS_VIEW_ICON_CONTROLLER (user_data);
     target_name = g_variant_get_string (value, NULL);
-    sorts_constants = get_sorts_constants_from_action_target_name (target_name);
-    sort_data.sort_type = sorts_constants->sort_type;
-    sort_data.reversed = sorts_constants->reversed;
+    sort_constants = get_sorts_constants_from_action_target_name (target_name);
+    sort_data.sort_type = sort_constants->sort_type;
+    sort_data.reversed = sort_constants->reversed;
     sort_data.directories_first = nautilus_files_view_should_sort_directories_first (NAUTILUS_FILES_VIEW (self));
 
     nautilus_view_model_set_sort_type (self->model, &sort_data);
     set_directory_sort_metadata (nautilus_files_view_get_directory_as_file (NAUTILUS_FILES_VIEW (self)),
-                                 sorts_constants);
+                                 sort_constants);
 
     g_simple_action_set_state (action, value);
 }
